@@ -257,6 +257,86 @@ a_dbus_message_iter(DBusMessageIter *iter)
     return nargs;
 }
 
+static bool
+a_dbus_convert_value(lua_State *L, int idx, DBusMessageIter *iter)
+{
+    /* i is the type name, i+1 the value */
+    size_t len;
+    const char *type = lua_tolstring(globalconf.L, idx, &len);
+
+    if(!type || len < 1)
+        return false;
+
+    switch(*type)
+    {
+      case DBUS_TYPE_ARRAY:
+        {
+            DBusMessageIter subiter;
+            dbus_message_iter_open_container(iter, DBUS_TYPE_ARRAY,
+                                             type + 1,
+                                             &subiter);
+
+            int arraylen = lua_objlen(L, idx + 1);
+
+            if(arraylen % 2 != 0)
+                luaL_error(globalconf.L,
+                           "your D-Bus signal handling method returned wrong number of arguments");
+
+            /* Push the array */
+            lua_pushvalue(L, idx + 1);
+
+            for(int i = 1; i < arraylen; i += 2)
+            {
+                lua_rawgeti(L, -1, i);
+                lua_rawgeti(L, -2, i + 1);
+                if(!a_dbus_convert_value(L, -2, &subiter))
+                    return false;
+                lua_pop(L, 2);
+            }
+
+            /* Remove the array */
+            lua_pop(L, 1);
+
+            dbus_message_iter_close_container(iter, &subiter);
+        }
+        break;
+      case DBUS_TYPE_BOOLEAN:
+        {
+            dbus_bool_t b = lua_toboolean(globalconf.L, idx + 1);
+            dbus_message_iter_append_basic(iter, DBUS_TYPE_BOOLEAN, &b);
+        }
+        break;
+#define DBUS_MSG_RETURN_HANDLE_TYPE_STRING(dbustype) \
+      case dbustype: \
+        { \
+            const char *s = lua_tostring(globalconf.L, idx + 1); \
+            if(s) \
+                dbus_message_iter_append_basic(iter, dbustype, &s); \
+        } \
+        break;
+    DBUS_MSG_RETURN_HANDLE_TYPE_STRING(DBUS_TYPE_STRING)
+    DBUS_MSG_RETURN_HANDLE_TYPE_STRING(DBUS_TYPE_BYTE)
+#undef DBUS_MSG_RETURN_HANDLE_TYPE_STRING
+#define DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(type, dbustype) \
+      case dbustype: \
+        { \
+           type num = lua_tonumber(globalconf.L, idx + 1); \
+           dbus_message_iter_append_basic(iter, dbustype, &num); \
+        } \
+        break;
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(int16_t, DBUS_TYPE_INT16)
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(uint16_t, DBUS_TYPE_UINT16)
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(int32_t, DBUS_TYPE_INT32)
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(uint32_t, DBUS_TYPE_UINT32)
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(int64_t, DBUS_TYPE_INT64)
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(uint64_t, DBUS_TYPE_UINT64)
+    DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(double, DBUS_TYPE_DOUBLE)
+#undef DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER
+    }
+
+    return true;
+}
+
 /** Process a single request from D-Bus
  * \param dbus_connection  The connection to the D-Bus server.
  * \param msg  The D-Bus message request being sent to the D-Bus connection.
@@ -289,15 +369,15 @@ a_dbus_process_request(DBusConnection *dbus_connection, DBusMessage *msg)
 
     lua_setfield(globalconf.L, -2, "type");
 
-    lua_pushstring(globalconf.L, NONULL(interface));
+    lua_pushstring(globalconf.L, interface);
     lua_setfield(globalconf.L, -2, "interface");
 
     const char *s = dbus_message_get_path(msg);
-    lua_pushstring(globalconf.L, NONULL(s));
+    lua_pushstring(globalconf.L, s);
     lua_setfield(globalconf.L, -2, "path");
 
     s = dbus_message_get_member(msg);
-    lua_pushstring(globalconf.L, NONULL(s));
+    lua_pushstring(globalconf.L, s);
     lua_setfield(globalconf.L, -2, "member");
 
     if(dbus_connection == dbus_connection_system)
@@ -319,7 +399,7 @@ a_dbus_process_request(DBusConnection *dbus_connection, DBusMessage *msg)
     else
     {
         signal_t *sig = signal_array_getbyid(&dbus_signals,
-                                             a_strhash((const unsigned char *) interface));
+                                             a_strhash((const unsigned char *) NONULL(interface)));
         if(sig)
         {
             /* there can be only ONE handler to send reply */
@@ -336,52 +416,15 @@ a_dbus_process_request(DBusConnection *dbus_connection, DBusMessage *msg)
 
             dbus_message_iter_init_append(reply, &iter);
 
+            if(n % 2 != 0)
+                luaL_error(globalconf.L,
+                           "your D-Bus signal handling method returned wrong number of arguments");
+
             /* i is negative */
             for(int i = n; i < 0; i += 2)
             {
-                /* i is the type name, i+1 the value */
-                size_t len;
-                const char *type = lua_tolstring(globalconf.L, i, &len);
-
-                if(!type || len != 1)
-                {
-                    luaA_warn(globalconf.L,
-                              "your D-Bus signal handling method returned bad data");
-                    break;
-                }
-
-                switch(*type)
-                {
-                  case DBUS_TYPE_BOOLEAN:
-                    {
-                        dbus_bool_t  b = lua_toboolean(globalconf.L, i + 1);
-                        dbus_message_iter_append_basic(&iter, DBUS_TYPE_BOOLEAN, &b);
-                    }
-                    break;
-#define DBUS_MSG_RETURN_HANDLE_TYPE_STRING(dbustype) \
-                  case dbustype: \
-                                 if((s = lua_tostring(globalconf.L, i + 1))) \
-                    dbus_message_iter_append_basic(&iter, dbustype, &s); \
-                    break;
-                    DBUS_MSG_RETURN_HANDLE_TYPE_STRING(DBUS_TYPE_STRING)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_STRING(DBUS_TYPE_BYTE)
-#undef DBUS_MSG_RETURN_HANDLE_TYPE_STRING
-#define DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(type, dbustype) \
-                  case dbustype: \
-                                 { \
-                                     type num = lua_tonumber(globalconf.L, i + 1); \
-                                     dbus_message_iter_append_basic(&iter, dbustype, &num); \
-                                 } \
-                        break;
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(int16_t, DBUS_TYPE_INT16)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(uint16_t, DBUS_TYPE_UINT16)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(int32_t, DBUS_TYPE_INT32)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(uint32_t, DBUS_TYPE_UINT32)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(int64_t, DBUS_TYPE_INT64)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(uint64_t, DBUS_TYPE_UINT64)
-                        DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER(double, DBUS_TYPE_DOUBLE)
-#undef DBUS_MSG_RETURN_HANDLE_TYPE_NUMBER
-                }
+                if(!a_dbus_convert_value(globalconf.L, i, &iter))
+                    luaL_error(globalconf.L, "your D-Bus signal handling method returned bad data");
 
                 lua_remove(globalconf.L, i);
                 lua_remove(globalconf.L, i + 1);
